@@ -126,9 +126,12 @@ class Deployer(object):
     def _source_files(self):
         # Running files to create subclasses.
         # TODO: Change these from hardcoded to dynamic.
-        exec(open("queues.py").read())
-        exec(open("function.py").read())
-        exec(open("api.py").read())
+        if os.path.isfile("queues.py"):
+            exec(open("queues.py").read())
+        if os.path.isfile("function.py"):
+            exec(open("function.py").read())
+        if os.path.isfile("api.py"):
+            exec(open("api.py").read())
 
     def _build_template(self, output_dir=None):
         # Checking custom output directory.
